@@ -5,6 +5,7 @@
 import hashlib
 import json
 import os
+import multiprocessing
 import tempfile
 from concurrent import futures
 from optparse import OptionParser
@@ -118,6 +119,11 @@ class XtractorCommand(Subcommand):
         self.cfg_count_only = options.count_only
         self.cfg_quiet = options.quiet
 
+        # Auto Thread Count
+        if self.cfg_threads == 0:
+            self.cfg_threads = multiprocessing.cpu_count()
+            self._say("Adjusting max threads to CPU count: {0}".format(self.cfg_threads), True)
+
         self.lib = lib
         self.query = decargs(arguments)
 
@@ -173,7 +179,7 @@ class XtractorCommand(Subcommand):
 
     def run_full_analysis(self, item):
         self._run_analysis(item)
-        # self._run_write_to_item(item)
+        self._run_write_to_item(item)
 
         # Delete output files (if config wants)
         if self.config["keep_output"].exists() and not self.config["keep_output"].get():
@@ -240,8 +246,9 @@ class XtractorCommand(Subcommand):
         self._say("Output: {0}".format(output_path))
         self._say("Profile: {0}".format(profile_path))
 
-        proc = Popen([extractor_path, input_path, output_path, profile_path],
-                     stdout=PIPE, stderr=PIPE)
+        cmd_and_args = [extractor_path, input_path, output_path, profile_path]
+        self._say("Executing: {0}".format(' '.join(f'"{a}"' for a in cmd_and_args)))
+        proc = Popen(cmd_and_args, stdout=PIPE, stderr=PIPE)
         stdout, stderr = proc.communicate()
 
         self._say("The process exited with code: {0}".format(proc.returncode))
@@ -256,13 +263,19 @@ class XtractorCommand(Subcommand):
         total = len(items)
         finished = 0
         with futures.ThreadPoolExecutor(max_workers=self.cfg_threads) as e:
+            if total and not self.cfg_quiet:
+                self._show_progress(finished, total)
             for _ in e.map(func, items):
                 finished += 1
-                # todo: show a progress bar (--progress-only option)
+                if not self.cfg_quiet:
+                    self._show_progress(finished, total)
+
+    def _show_progress(self, done, total):
+        print('Finished: [%d/%d]\r' % (done, total), end="")
 
     def _get_output_path_for_item(self, item: Item):
         identifier = item.get("mb_trackid")
-        if not identifier:
+        if not identifier or '/' in identifier:
             input_path = self._get_input_path_for_item(item)
             identifier = hashlib.md5(input_path.encode('utf-8')).hexdigest()
 
